@@ -4,7 +4,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use overload
   '""'     => sub { shift->to_string },
@@ -523,15 +523,15 @@ C<< iter >> returns the next IP in block, starting with base and stopping at las
 
   OUTPUT:
 
-  fe80::affe
-  fe80::afff
-  fe80::b000
-  fe80::b001
+  2001:db8::affe
+  2001:db8::afff
+  2001:db8::b000
+  2001:db8::b001
   ...
-  fe80::cafb
-  fe80::cafc
-  fe80::cafd
-  fe80::cafe
+  2001:db8::cafb
+  2001:db8::cafc
+  2001:db8::cafd
+  2001:db8::cafe
 
 =cut
 
